@@ -1,11 +1,10 @@
 # ABSTRACT: Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 package PONAPI::Client;
 
-our $VERSION = '0.002008';
+our $VERSION = '0.002009';
 
 use Moose;
 
-use Hijk;
 use JSON::MaybeXS qw( decode_json );
 
 use PONAPI::Client::Request::Create;
@@ -49,6 +48,12 @@ has 'uri_base' => (
     default => sub { '' },
 );
 
+has ua => (
+    is      => 'ro',
+    does    => 'PONAPI::Client::Role::UA',
+    lazy    => 1,
+    builder => '_build_hijk_ua',
+);
 
 ### public methods
 
@@ -112,10 +117,12 @@ sub delete_relationships {
     return $self->_send_ponapi_request( $request->request_params );
 }
 
-
 ### private methods
 
-use constant OLD_HIJK => $Hijk::VERSION lt '0.16';
+sub build_hijk_ua {
+    require PONAPI::Client::UA::Hijk;
+    return PONAPI::Client::UA::Hijk->new();
+}
 
 sub _args {
     my $self = shift;
@@ -125,8 +132,18 @@ sub _args {
 }
 
 sub _http_request {
-    $_[1]->{parse_chunked} = 1;
-    return Hijk::request($_[1]);
+    my ($self) = @_;
+    return $self->ua->send_http_request($_[1]);
+}
+
+my %DEFAULT_HEADER_OVERRIDE;
+
+# $self->add_to_default_headers([ header1 => value1 ], [header2 => value2], ...)
+
+sub add_to_default_headers {
+    my ($self, @headers) = @_;
+
+    $DEFAULT_HEADER_OVERRIDE{$_->[0]} = $_->[1] for @headers;
 }
 
 sub _send_ponapi_request {
@@ -142,7 +159,8 @@ sub _send_ponapi_request {
     ($status, $content) = do {
         local $@;
         eval {
-            my $res = $self->_http_request({
+
+            my $request = {
                 %args,
                 host => $self->host,
                 port => $self->port,
@@ -156,15 +174,17 @@ sub _send_ponapi_request {
                         ? ( 'X-PONAPI-Escaped-Values' => '1' )
                         : ()
                     ),
+                    %DEFAULT_HEADER_OVERRIDE,
                 ],
-            });
+            };
+
+            $self->ua->before_request($request);
+
+            my $res = $self->_http_request($request);
             $status  = $res->{status};
 
-            if ( OLD_HIJK ) {
-                if ( ($res->{head}{'Transfer-Encoding'}||'') eq 'chunked' ) {
-                    die "Got a chunked response from the server, but this version of Hijk can't handle those; please upgrade to at least Hijk 0.16";
-                }
-            }
+            $self->ua->after_request($res);
+
             $content = $res->{body} ? decode_json( $res->{body} ) : '';
             1;
         }
@@ -200,7 +220,7 @@ PONAPI::Client - Client to a {JSON:API} service (http://jsonapi.org/) v1.0
 
 =head1 VERSION
 
-version 0.002008
+version 0.002009
 
 =head1 SYNOPSIS
 
